@@ -15,7 +15,6 @@ scipy_deps = ["pip", "setuptools", "numpy", "scipy", "pandas", "matplotlib"]
 
 
 skhep_deps = [
-    "awkward0",
     "awkward",
     "boost_histogram",
     "decaylanguage",
@@ -26,10 +25,9 @@ skhep_deps = [
     "iminuit",
     "mplhep",
     "particle",
+    "resample",
     "skhep",
     "uproot",
-    "uproot3",
-    "uproot3_methods",
     "vector",
 ]
 
